map_3d: geographic coordinates conversions
Enums
Constants
- EARTH_
RADIUS - Earth radius (m)
Functions
- aer2ecef
- Returns the tuple (x,y,z) of coordinates in the ECEF system
- aer2eci
- Returns the tuple (x,y,z) of coordinates in the ECI system
- aer2enu
- Returns the tuple (east,north,up) of coordinates in the ENU system
- aer2geodetic
- Returns the tuple (latitude,longitude,altitude) of coordinates in the Geodetic system
- aer2ned
- Returns the tuple (north,east,down) of coordinates in the NED system
- deg2rad
Deprecated - Returns the radians [rad] value of the decimal degree [deg] input
- distance
- Returns distance (m) between two decimal degrees coordinates:: coord1: (lat,lon), coord2: (lat, lon)
- ecef2aer
- Returns the tuple (azimuth,elevation,slant range) of coordinates in the AER system
- ecef2eci
- Returns the tuple (x,y,z) of coordinates in the ECI system
- ecef2enu
- Returns the tuple (east,north,up) of coordinates in the ENU system
- ecef2geodetic
- Returns the tuple (latitude,longitude,altitude) of coordinates in the Geodetic system with desired reference frame. Returns NaN for lat, lon, alt if the input ECEF coordinates are at the center of the Earth.
- ecef2ned
- Returns the tuple (north,east,down) of coordinates in the NED system
- eci2aer
- Returns the tuple (azimuth,elevation,slant range) of coordinates in the AER system
- eci2ecef
- Returns the tuple (x,y,z) of coordinates in the ECEF system
- enu2aer
- Returns the tuple (azimuth,elevation,slant range) of coordinates in the AER system
- enu2ecef
- Returns the tuple (x,y,z) of coordinates in the ECEF system
- enu2geodetic
- Returns the tuple (latitude,longitude,altitude) of coordinates in the Geodetic system
- enu2uvw
- Returns the tuple (u,v,w) of coordinates in the local vector system
- fix
Deprecated - Return the round toward zero value of the input
- geodetic2aer
- Returns the tuple (azimuth,elevation,slant range) of coordinates in the AER system
- geodetic2ecef
- Returns the tuple (x,y,z) of coordinates in the ECEF system with desired reference frame.
- geodetic2enu
- Returns the tuple (east,north,up) of coordinates in the ENU system
- geodetic2ned
- Returns the tuple (north,east,down) of coordinates in the NED system
- get_
radius_ normal - Returns the normal radius based on given latitude and desired reference frame
- matmul3
- Returns the array result of 3-by-3-matrix that multiplies a 3-by-1 column array
- ned2aer
- Returns the tuple (azimuth,elevation,slant range) of coordinates in the AER system
- ned2ecef
- Returns the tuple (x,y,z) of coordinates in the ECEF system
- ned2geodetic
- Returns the tuple (latitude,longitude,altitude) of coordinates in the Geodetic system
- r3
- Returns the array representing a 3-by-3 rotation matrix of the input
- rad2deg
Deprecated - Returns the decimal degree [deg] value of the radians [rad] input
- transpose3
- Returns the array representing the transpose of the input 3-by-3 matrix
- utc2gst
- Returns the GST time as f64
- uvw2enu
- Returns the tuple (east,north,up) of coordinates in the ENU system